"use strict";

/* exported logger */

var AbstractGuiElement = require('./AbstractGuiElement');
var GuiConnector = require('../GuiConnector');
var InvalidCredentialsError = require('../InvalidCredentialsError');
var PanelControlElementType = require('./PanelControlElementType');

var Functions = require('../functions');
var logger = require('../logger');

function LoginDialog(params) {
  AbstractGuiElement.call(this, params);
  var self = this;
  self._createLoginTab();
  $(self.getElement()).dialog({
    autoOpen : false,
    resizable : false,
  });

  var loginButton = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_BUTTON);
  loginButton.onclick = function() {
    var login = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_INPUT_TEXT).value;
    var password = self.getControlElement(PanelControlElementType.USER_TAB_PASSOWRD_INPUT_TEXT).value;

    return ServerConnector.login(login, password).then(function() {
      window.location.reload(false);
    }).then(null, function(error) {
      if (error instanceof InvalidCredentialsError) {
        GuiConnector.alert("invalid credentials");
      } else {
        GuiConnector.alert(error);
      }
    });
  };

}

LoginDialog.prototype = Object.create(AbstractGuiElement.prototype);
LoginDialog.prototype.constructor = LoginDialog;

LoginDialog.prototype.createTableRow = function(elements) {
  var row = Functions.createElement({
    type : "div",
    style : "display: table-row;"
  });

  for (var i = 0; i < elements.length; i++) {
    var cell = Functions.createElement({
      type : "div",
      style : "display: table-cell;"
    });
    cell.appendChild(elements[i]);
    row.appendChild(cell);
  }
  return row;
};

LoginDialog.prototype._createLoginTab = function() {
  var self = this;

  var authorizationFormTab = Functions.createElement({
    type : "div",
    style : "width:100%;display: table;border-spacing: 10px;"
  });
  this.getElement().appendChild(authorizationFormTab);

  var loginLabel = Functions.createElement({
    type : "div",
    content : "LOGIN:"
  });
  var loginInput = Functions.createElement({
    type : "input",
    inputType : "text",
    style : "width:100%",
    name : "loginText"
  });
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_INPUT_TEXT, loginInput);

  authorizationFormTab.appendChild(self.createTableRow([ loginLabel, loginInput ]));

  var passwordLabel = Functions.createElement({
    type : "div",
    content : "PASSWORD:"
  });
  var passwordInput = Functions.createElement({
    type : "input",
    inputType : "password",
    style : "width:100%",
    name : "passwordText"
  });
  this.setControlElement(PanelControlElementType.USER_TAB_PASSOWRD_INPUT_TEXT, passwordInput);

  authorizationFormTab.appendChild(self.createTableRow([ passwordLabel, passwordInput ]));

  var centerTag = Functions.createElement({
    type : "center"
  });
  this.getElement().appendChild(centerTag);

  var loginButton = Functions.createElement({
    type : "button",
    name : "loginButton",
    content : "LOGIN"
  });
  centerTag.appendChild(loginButton);
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_BUTTON, loginButton);

};

LoginDialog.prototype.open = function() {
  var self = this;
  $(self.getElement()).dialog('option', 'title', 'AUTHORIZATION FORM');
  $(self.getElement()).dialog("open");
};

LoginDialog.prototype.destroy = function() {
  $(this.getElement()).dialog("destroy");
};

module.exports = LoginDialog;
