"use strict";

/* exported logger */

var AbstractGuiElement = require('../AbstractGuiElement');
var GuiConnector = require('../../GuiConnector');

var Functions = require('../../functions');
var logger = require('../../logger');

var guiUtils = new (require('../leftPanel/GuiUtils'))();

function EditProjectDialog(params) {
  AbstractGuiElement.call(this, params);
  var self = this;
  $(self.getElement()).addClass("minerva-edit-project-dialog");

  self.createGui();
}

EditProjectDialog.prototype = Object.create(AbstractGuiElement.prototype);
EditProjectDialog.prototype.constructor = EditProjectDialog;

EditProjectDialog.prototype.createGui = function() {
  var self = this;
  var element = self.getElement();

  var tabDiv = Functions.createElement({
    type : "div",
    name : "tabView",
    className : "tabbable boxed parentTabs"
  });
  element.appendChild(tabDiv);

  var tabMenuDiv = Functions.createElement({
    type : "ul",
    className : "nav nav-tabs"
  });
  tabDiv.appendChild(tabMenuDiv);

  var tabContentDiv = Functions.createElement({
    type : "div",
    className : "tab-content"
  });
  tabDiv.appendChild(tabContentDiv);

  self.createGeneralTab(tabMenuDiv, tabContentDiv);
  self.createOverlaysTab(tabMenuDiv, tabContentDiv);
  self.createUsersTab(tabMenuDiv, tabContentDiv);
};

EditProjectDialog.prototype.createGeneralTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "GENERAL",
    id : self.getProject().getProjectId() + "_general_tab",
    content : self.createGeneralTabContent(),
  });

};

EditProjectDialog.prototype.addTab = function(params) {
  var navLi = guiUtils.createTabMenuObject({
    id : params.id,
    name : params.name,
    navigationBar : params.tabMenuDiv
  });
  params.tabMenuDiv.appendChild(navLi);

  var contentDiv = guiUtils.createTabContentObject({
    id : params.id,
    navigationObject : navLi,
    navigationBar : params.tabMenuDiv
  });

  if (params.content !== undefined) {
    contentDiv.appendChild(params.content);
  }

  params.tabContentDiv.appendChild(contentDiv);
};

EditProjectDialog.prototype.createGeneralTabContent = function() {
  var self = this;
  var project = self.getProject();

  var result = new Functions.createElement({
    type : "div",
  });

  var table = new Functions.createElement({
    type : "div",
    style : "display:table"
  });
  result.appendChild(table);

  var projectIdRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(projectIdRow);
  projectIdRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "ProjectId",
  }));
  projectIdRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : project.getProjectId(),
  }));

  var nameRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(nameRow);
  nameRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "Name",
  }));
  nameRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "<input value='" + project.getName() + "'/>",
  }));

  var versionRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(versionRow);
  versionRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "Version",
  }));
  versionRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "<input value='" + project.getVersion() + "'/>",
  }));

  var diseaseRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(diseaseRow);
  diseaseRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "Disease",
  }));
  var disease = "";
  if (project.getDisease() !== undefined) {
    disease = project.getDisease().getResource();
  }
  diseaseRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "<input value='" + disease + "'/>",
  }));

  var organismRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(organismRow);
  organismRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "Organism",
  }));
  var organism = "";
  if (project.getOrganism() !== undefined) {
    organism = project.getOrganism().getResource();
  }
  organismRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "<input value='" + organism + "'/>",
  }));

  var emailRow = new Functions.createElement({
    type : "div",
    style : "display:table-row"
  });
  table.appendChild(emailRow);
  emailRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "Notify email",
  }));
  var email = "";
  if (project.getNotifyEmail() !== undefined) {
    email = project.getNotifyEmail();
  }
  emailRow.appendChild(new Functions.createElement({
    type : "div",
    style : "display:table-cell",
    content : "<input value='" + email + "'/>",
  }));

  var menuRow = Functions.createElement({
    type : "div",
    className : "minerva-menu-row",
    style : "display:table-row; margin:10px",
  });
  result.appendChild(menuRow);

  var saveProjectButton = Functions.createElement({
    type : "button",
    name : "saveProject",
    content : '<span class="ui-icon ui-icon-disk"></span>&nbsp;SAVE',
    onclick : function() {
      return self.onSaveClicked().then(null, GuiConnector.alert);
    },
  });
  var cancelButton = Functions.createElement({
    type : "button",
    name : "cancelProject",
    content : '<span class="ui-icon ui-icon-cancel"></span>&nbsp;CANCEL',
    onclick : function() {
      return self.close();
    },
  });
  menuRow.appendChild(saveProjectButton);
  menuRow.appendChild(cancelButton);

  return result;

};

EditProjectDialog.prototype.createOverlaysTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "OVERLAYS",
    id : self.getProject().getProjectId() + "_overlays_tab",
    content : self.createOverlaysTabContent(),
  });
};

EditProjectDialog.prototype.createOverlaysTabContent = function() {
  return Functions.createElement({
    type : "div",
    content : "Helo"
  });
};

EditProjectDialog.prototype.createUsersTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "USERS",
    id : self.getProject().getProjectId() + "_users_tab",
    content : self.createUsersTabContent(),
  });
};

EditProjectDialog.prototype.createUsersTabContent = function() {
  return Functions.createElement({
    type : "div",
    content : "Bye",
  });
};

EditProjectDialog.prototype.init = function() {
};

EditProjectDialog.prototype.destroy = function() {
  $(this.getElement()).dialog("destroy");
};

EditProjectDialog.prototype.open = function() {
  var self = this;
  var div = self.getElement();
  if (!$(div).hasClass("ui-dialog-content")) {
    $(div).dialog({
      title : self.getProject().getProjectId(),
      width : 400,
    });
  }
  $(div).dialog("open");
};

EditProjectDialog.prototype.close = function() {
  $(this.getElement()).dialog("close");
};

module.exports = EditProjectDialog;
