"use strict";

var Promise = require("bluebird");

/* exported logger */
var logger = require('../../logger');

var AbstractDbPanel = require('./AbstractDbPanel');
var PanelControlElementType = require('../PanelControlElementType');

function ChemicalPanel(params) {
  params.panelName = "chemical";
  params.helpTip = '<p>source: Comparative Toxicogenomics Database <a target="_ctd" href="http://ctdbase.org/">ctdbase.org</a></p>'
      + '<p>use only the full name of chemicals according to <a target="_ctd_chemicals" href="http://ctdbase.org/voc.go?type=chem"> ctdbase/chem</a> for search</p>'
      + '<p>only curated associations between genes and chemicals with direct evidence to '
      + 'Parkinson Disease (<a href="http://bioportal.bioontology.org/ontologies/1351?p=terms&conceptid=D010300" target="_blank">D010300</a>) are displayed</p>'
      + '<p>separate multiple search by semicolon';
  params.placeholder = "full chemical name (CTD)";

  AbstractDbPanel.call(this, params);

  if (this.getMap().getProject().getDisease() === undefined) {
    this.disablePanel("DISEASE NOT DEFINED FOR PROJECT. PLEASE, DEFINE IT IN THE ADMIN SECTION.");
  }
}
ChemicalPanel.prototype = Object.create(AbstractDbPanel.prototype);
ChemicalPanel.prototype.constructor = ChemicalPanel;

ChemicalPanel.prototype.createPreamble = function(chemical) {
  var self = this;
  var guiUtils = self.getGuiUtils();
  var result = document.createElement("div");
  if (chemical === undefined || chemical.getName() === undefined) {
    result.appendChild(guiUtils.createLabel("NOT FOUND"));
  } else {
    result.appendChild(guiUtils.createParamLine("Chemical: ", chemical.getName()));
    result.appendChild(guiUtils.createParamLine("Description: ", chemical.getDescription()));
    result.appendChild(guiUtils.createArrayParamLine("Synonyms: ", chemical.getSynonyms()));
    result.appendChild(guiUtils.createParamLine("Direct Evidence: ", chemical.getDirectEvidence()));
    result.appendChild(guiUtils
        .createAnnotations("Directe Evidence Publications: ", chemical.getDirectEvidenceReferences()));
    result.appendChild(guiUtils.createAnnotations("Sources: ", chemical.getReferences()));
    result.appendChild(guiUtils.createNewLine());
  }

  return result;
};

ChemicalPanel.prototype.createTableElement = function(target, icon) {
  return this.createTargetRow(target, icon);
};

ChemicalPanel.prototype.searchByQuery = function() {
  var self = this;
  var query = self.getControlElement(PanelControlElementType.SEARCH_INPUT).value;

  return self.getOverlayDb().searchByQuery(query);
};

ChemicalPanel.prototype.init = function() {
  var query = ServerConnector.getSessionData().getChemicalQuery();
  if (query !== undefined) {
    return this.getOverlayDb().searchByEncodedQuery(query);
  } else {
    return Promise.resolve();
  }
};

module.exports = ChemicalPanel;
