"use strict";

require('../../mocha-config.js');

var Drug = require('../../../../main/js/map/data/Drug');
var DrugPanel = require('../../../../main/js/gui/leftPanel/DrugPanel');
var PanelControlElementType = require('../../../../main/js/gui/PanelControlElementType');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('DrugPanel', function() {

  it('contructor', function() {
    var map = helper.createCustomMap();
    helper.createDrugDbOverlay(map);

    new DrugPanel({
      element : testDiv,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('createDrugeader for empty', function() {
    var map = helper.createCustomMap();
    helper.createDrugDbOverlay(map);

    var panel = new DrugPanel({
      element : testDiv,
      customMap : map
    });

    assert.ok(panel.createPreamble().innerHTML.indexOf("NOT FOUND") > 0);
  });

  it('createDrugeader for empty', function() {
    var map = helper.createCustomMap();
    helper.createDrugDbOverlay(map);

    var panel = new DrugPanel({
      element : testDiv,
      customMap : map
    });

    assert.ok(panel.createPreamble(new Drug()).innerHTML.indexOf("NOT FOUND") > 0);
  });

  it('on searchResults changed', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var drugDbOverlay = helper.createDrugDbOverlay(map);

    new DrugPanel({
      element : testDiv,
      customMap : map
    });

    return drugDbOverlay.searchByQuery("aspirin").then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("Acetylsalicylic acid") >= 0);
    });
  });

  it('searchByQuery', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createDrugDbOverlay(map);

    var panel = new DrugPanel({
      element : testDiv,
      customMap : map
    });

    panel.getControlElement(PanelControlElementType.SEARCH_INPUT).value = "aspirin";

    return panel.searchByQuery().then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("Acetylsalicylic acid") >= 0);
    });
  });

});
