"use strict";

var TouchMap = require('../../../main/js/map/TouchMap');
var chai = require('chai');
var assert = chai.assert;

describe('TouchMap', function() {
  it("simple contructor", function() {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);
    assert.ok(touchMap);
  });

  it("TouchMap handleStart", function() {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);

    assert.notOk(touchMap.firstFingerId);

    var evt = document.createEvent('UIEvent');
    evt.initUIEvent('touchstart', true, true, window, null);

    evt.changedTouches = [ {
      pageX : 200,
      pageY : 200,
      identifier : 1,
      clientX : 100,
      clientY : 100
    } ];

    touchMap.handleStart(evt);
    assert.ok(touchMap.firstFingerId);
  });

  it("TouchMap updateCoordinates", function() {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);
    touchMap.firstFingerId = 1;

    var evt = document.createEvent('UIEvent');
    evt.initUIEvent('touchstart', true, true, window, null);

    evt.changedTouches = [ {
      pageX : 200,
      pageY : 200,
      identifier : 1,
      clientX : 100,
      clientY : 100
    } ];

    assert.notOk(touchMap.firstEndX);
    assert.notOk(touchMap.firstEndY);
    touchMap.updateCoordinates(evt.changedTouches[0]);
    assert.ok(touchMap.firstEndX);
    assert.ok(touchMap.firstEndY);
  });

  it("TouchMap lineDistance", function() {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);

    var dist = touchMap.lineDistance(1, 1, 4, 5);
    assert.equal(5, dist);
  });
});
